==> haskell-sayable-1.2.5.0-1-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sayable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sayable
version:              1.2.5.0
visibility:           public
id:                   sayable-1.2.5.0-FmgbPHyP2WFv8IZVYMWKs
key:                  sayable-1.2.5.0-FmgbPHyP2WFv8IZVYMWKs
license:              ISC
copyright:            Galois Inc., 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Construction of context-adjusted pretty output
description:

    This package provides a set of data structures, classes and operators that
    facilitate the construction of a Prettyprinter Doc object.  The difference
    between this an Prettyprinter is:

    * Additional "saytag" parameter that can be used to control the Doc rendering.

    * Brevity of syntax (using operators) designed to enhance conversion of
    arguments and readability of messages and conversion

category:             Text
abi:                  ff52c1e8ba1a769f545a3b1e20f6d107
exposed:              True
exposed-modules:      Text.Sayable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sayable
hs-libraries:         HSsayable-1.2.5.0-FmgbPHyP2WFv8IZVYMWKs
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 prettyprinter-1.7.1-3DaP0TCP9KiHFF7Mogrhb2
    template-haskell-2.19.0.0 text-2.0.2
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-sayable/html/sayable.haddock
haddock-html:         /usr/share/doc/haskell-sayable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sayable-1.2.5.0-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sayable.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 sayable
version:              1.2.5.0
visibility:           public
id:                   sayable-1.2.5.0-5ndl6m8mdxMIaw9ij3lNCG
key:                  sayable-1.2.5.0-5ndl6m8mdxMIaw9ij3lNCG
license:              ISC
copyright:            Galois Inc., 2023
maintainer:           kquick@galois.com
author:               Kevin Quick
synopsis:             Construction of context-adjusted pretty output
description:

    This package provides a set of data structures, classes and operators that
    facilitate the construction of a Prettyprinter Doc object.  The difference
    between this an Prettyprinter is:

    * Additional "saytag" parameter that can be used to control the Doc rendering.

    * Brevity of syntax (using operators) designed to enhance conversion of
    arguments and readability of messages and conversion

category:             Text
abi:                  512b47a05239fd64a23bf41f221abd41
exposed:              True
exposed-modules:      Text.Sayable
import-dirs:          /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/sayable-1.2.5.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-sayable
hs-libraries:         HSsayable-1.2.5.0-5ndl6m8mdxMIaw9ij3lNCG
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7
    exceptions-0.10.5 prettyprinter-1.7.1-K49FGRh0RcS7wKSRgaQVIq
    template-haskell-2.19.0.0 text-2.0.2
    th-abstraction-0.5.0.0-BROQwjXmGCt8uLmQUfLqOy

haddock-interfaces:   /usr/share/doc/haskell-sayable/html/sayable.haddock
haddock-html:         /usr/share/doc/haskell-sayable/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
